import { parseQueryString } from '@s-ui/js/lib/string';

var getServerStrategy = function getServerStrategy() {
  return {
    getVariation: function getVariation(_ref) {
      var pde = _ref.pde,
          experimentName = _ref.experimentName,
          attributes = _ref.attributes;
      return pde.getVariation({
        pde: pde,
        name: experimentName,
        attributes: attributes
      });
    },
    trackExperiment: function trackExperiment() {},
    getForcedValue: function getForcedValue() {}
  };
};

var getBrowserStrategy = function getBrowserStrategy(_ref2) {
  var customTrackExperimentViewed = _ref2.customTrackExperimentViewed;
  return {
    getVariation: function getVariation(_ref3) {
      var pde = _ref3.pde,
          experimentName = _ref3.experimentName,
          attributes = _ref3.attributes;
      var variationName = pde.activateExperiment({
        name: experimentName,
        attributes: attributes
      });
      return variationName;
    },
    trackExperiment: function trackExperiment(_ref4) {
      var _window$analytics;

      var variationName = _ref4.variationName,
          experimentName = _ref4.experimentName;

      if (customTrackExperimentViewed) {
        return customTrackExperimentViewed({
          variationName: variationName,
          experimentName: experimentName
        });
      } // user is not part of the experiment


      if (!variationName) return;

      if (!((_window$analytics = window.analytics) != null && _window$analytics.track)) {
        // eslint-disable-next-line no-console
        console.error("[sui-pde: useExperiment] window.analytics.track expected to exists but doesn't");
        return;
      }

      window.analytics.ready(function () {
        window.analytics.track('Experiment Viewed', {
          experimentName: experimentName,
          variationName: variationName
        });
      });
    },

    /**
     * @param {object} param
     * @param {string} key Experiment or feature flag key
     * @param {string} queryString Test purposes only
     * @returns {string|null}
     */
    getForcedValue: function getForcedValue(_ref5) {
      var key = _ref5.key,
          _ref5$queryString = _ref5.queryString,
          queryString = _ref5$queryString === void 0 ? document.location.search : _ref5$queryString;
      var queryParams = parseQueryString(queryString);
      return queryParams["suipde_" + key];
    }
  };
};
/**
 * Returns the implementation of experiment related methods depending on
 * which platform we are server/browser
 * @param {object} param
 * @param {function} [param.customTrackExperimentViewed]
 * @returns object
 */


export var getPlatformStrategy = function getPlatformStrategy(_temp) {
  var _ref6 = _temp === void 0 ? {} : _temp,
      customTrackExperimentViewed = _ref6.customTrackExperimentViewed;

  var isNode = typeof window === 'undefined';

  if (isNode) {
    return getServerStrategy();
  }

  return getBrowserStrategy({
    customTrackExperimentViewed: customTrackExperimentViewed
  });
};