import { useContext } from 'react';
import PdeContext from '../contexts/PdeContext';
import { getPlatformStrategy } from './platformStrategies';
/**
 * Hook to use a feature toggle
 * @param {string} featureKey
 * @param {object} attributes
 * @param {string} [queryString] test purposes only
 * @return {{isActive: boolean}}
 */

export default function useFeature(featureKey, attributes, queryString) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useFeature] sui-pde provider is required to work');
  var strategy = getPlatformStrategy();
  var forcedValue = strategy.getForcedValue({
    key: featureKey,
    queryString: queryString
  });

  if (forcedValue) {
    return {
      isActive: forcedValue === 'on'
    };
  }

  var isActive;

  try {
    isActive = pde.isFeatureEnabled({
      featureKey: featureKey,
      attributes: attributes
    });
  } catch (error) {
    console.error(error);
    isActive = false;
  }

  return {
    isActive: isActive
  };
}